@@ -1,4 +1,4 @@
-package Pcore::XMPP v0.6.2;
+package Pcore::XMPP v0.7.0;
 
 use Pcore -dist;
 
@@ -15,15 +15,13 @@ Pcore::XMPP
 =head1 SYNOPSIS
 
     # create handle
-    H->add(
-        jabber => 'xmpp',
-        addr   => 'xmpp://username:password@gmail.com?gtalk',
-    );
+    my $xmpp = Pcore::Handle->new('xmpp://username:password@gmail.com?gtalk');
 
-    H->jabber->sendmsg( 'to_user@gmail.com', 'message' );
+    # send message
+    $xmpp->sendmsg( 'to_user@gmail.com', 'message' );
 
     # create log channel
-    P->log->add( 'Channel-Name', 'xmpp://username:password@gmail.com?gtalk&to=to_user@gmail.com' );
+    P->log->add( 'channel', 'xmpp://username:password@gmail.com?gtalk&to=to_user@gmail.com' );
 
 =head1 DESCRIPTION
 
